@@ -10,20 +10,18 @@
 #include <console/core/sample.h>
 #include <console/core/schemaentrytemplates.h>
 
+#include <QAbstractItemModelTester>
 #include <QDebug>
-#include <QtTest/qtest.h>
 #include <QObject>
 #include <QStandardPaths>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-#include <QAbstractItemModelTester>
-#endif
+#include <QtTest/qtest.h>
 
 using namespace KUserFeedback::Console;
 
 class NumericAggregationModelTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         Q_INIT_RESOURCE(schematemplates);
@@ -33,9 +31,7 @@ private slots:
     void testEmptyModel()
     {
         NumericAggregationModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester modelTest(&model);
-#endif
         model.setAggregation(AggregationElement());
         AggregationElement aggr;
         {
@@ -71,9 +67,7 @@ private slots:
     void testModelContent()
     {
         NumericAggregationModel model;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         QAbstractItemModelTester modelTest(&model);
-#endif
         AggregationElement aggr;
         {
             SchemaEntry entry;
