@@ -18,7 +18,7 @@ using namespace KUserFeedback::Console;
 class SampleTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         Q_INIT_RESOURCE(schematemplates);
